; This function calculates the nutation parameters
; dpsi, deps according to IAU 1980 nutation up to 0.01sec terms
; from S. Tab 3.222.1

 FUNCTION DPSIDEPS,tj,order=order

  nel=N_ELEMENTS(tj)
  IF NOT KEYWORD_SET(order) THEN order=3
  dtor=!dpi/180.0d
  dpde=DBLARR(nel,2)


  IF order LT 3 THEN BEGIN
   ; S. 3.225-4
   d0=tj*36525.0d
   dpde(*,1)=0.0026d*COS((-0.05295d*d0 + 125.0d)*dtor) + $
      0.0002d*COS((1.97129d*d0 + 200.9d)*dtor)

   dpde(*,0)=-0.0048d*SIN(((125.0d)-0.05295d*d0)*dtor)- $
      0.0004d*SIN(((200.9d)+1.97129d*d0)*dtor)
 
   RETURN,dpde*dtor

  ENDIF

  arg=( $
       [[0,0,0,0,1],[0,0,2,-2,2],[0,0,0,0,2],[0,1,0,0,0], $ ;1,9,2,10
       [0,1,2,-2,2],[0,-1,2,-2,2],[0,0,2,-2,1], $ ; 11,12,13
       [0,0,2,0,2],[1,0,0,0,0],[0,0,2,0,1],[1,0,2,0,2], $ ;31-34
       [1,0,0,-2,0],[-1,0,2,0,2]]) ; 35,36
  pcoeff=[[6798.4d,-171996.0d,-174.2d,92025.0d, 8.9d], $ ;1
          [ 182.6d, -13187.0d,  -1.6d, 5736.0d,-3.1d], $ ;9
          [3399.2d,   2062.0d,   0.2d, -895.0d, 0.5d], $ ;2
          [ 365.3d,   1426.0d,  -3.4d,   54.0d,-0.1d], $ ;10
          [ 121.7d,   -517.0d,   1.2d,  224.0d,-0.6d], $ ;11
          [ 365.2d,    217.0d,  -0.5d,  -95.0d, 0.3d], $ ;12
          [ 177.8d,    129.0d,   0.1d,  -70.0d, 0.0d], $ ;13
          [  13.7d,  -2274.0d,  -0.2d,  977.0d,-0.5d], $ ;31
          [  27.6d,    712.0d,   0.1d,   -7.0d, 0.0d], $ ;32
          [  13.6d,   -386.0d,  -0.4d,  200.0d, 0.0d], $ ;33
          [   9.1d,   -301.0d,   0.0d,  129.0d,-0.1d], $ ;34
          [  31.8d,   -158.0d,   0.0d,   -1.0d, 0.0d], $ ;35
          [  27.1d,    123.0d,   0.0d,  -53.0d, 0.0d]]   ;36

  nelarg=N_ELEMENTS(arg)/5
;  nelarg=2

  funarr=FUNDAMENTAL(tj)*dtor
  fun0arr=FUNDAMENTAL(0.0d)*dtor
  FOR j=0,nel-1 DO BEGIN
   tt=tj(j)
   FOR i=0,nelarg-1 DO BEGIN
     ai=(arg(*,i)##funarr(j,*))
 ;    print,ai(0)/dtor
 ;    print,arg(*,i)##(funarr(j,*)-fun0arr(j,*))/dtor

     dpde(j,0)=dpde(j,0)+(pcoeff(1,i)+pcoeff(2,i)*tt)*SIN(ai(0))
     dpde(j,1)=dpde(j,1)+(pcoeff(3,i)+pcoeff(4,i)*tt)*COS(ai(0))
     ;print,ai(0)/dtor,(pcoeff(1,i)+pcoeff(2,i)*tt)/3.6d7,(pcoeff(3,i)+pcoeff(4,i)*tt)/3.6d7
   ENDFOR
  ENDFOR
  
  ; convert to radian:
  dpde=dpde/3.6d7*dtor
 
 RETURN,dpde
 END
