; This function returns mean JDE200 geometric equatorial or ecliptic position
; on the equinox of J2000 for a given object relative to center.
; 
; INPUTS:
;
; targets: 0:   "SSB"
;          1:    "Mercury" 
;          2:    "Venus"
;          3:    EMB
;          4:    "Mars"
;          5:    "Jupiter"
;          6:    "Saturn"
;          7:    "Uranus";
;          8:    "Neptune"
;          9:    "Pluto"
;         10:    "Moon"
;         11:    "Sun"
;         12:    "Earth"
;         center by default SSB
; 
; startjd   DOUBLE fractional Julian day
; stepsize  INT    distance in days between 
; posonly   0/1  just return position vectors
; RETURNS:  ephstr={EPH,pos:DBLARR(1,3),vel:DBLARR(1,3),lon:0.0d,lat:0.0d,r:0.0d}
 
 FUNCTION GETJPL,target,jdarr,center=center,posonly=posonly

 IF N_ELEMENTS(count) LE 0 THEN count=1
 IF NOT KEYWORD_SET(center) THEN center=0
 
 xsize=N_ELEMENTS(jdarr)
 au=1.4959787d8


 FmtOpt="PosVel"
 EphName="/scratch/wjmf/ephem/jplde200/ascii/binEphem.200"
 targetarr=DBLARR(xsize,6)
 centerarr=DBLARR(xsize,6)
  
 IF target EQ 12 OR center EQ 12 OR target EQ 10 OR center EQ 10 THEN BEGIN
   embarr=DBLARR(xsize,6)
   s=CALL_EXTERNAL('jplde/getephem.so','get_ephem',EphName,jdarr,2,FmtOpt,xsize,embarr)
   moonarr=DBLARR(xsize,6)
   s=CALL_EXTERNAL('jplde/getephem.so','get_ephem',EphName,jdarr,9,FmtOpt,xsize,moonarr)
   emrat = 81.30056d
   
   ;see Murray p.44
   IF target EQ 12 THEN targetarr=embarr-moonarr/(1+emrat)
   IF center EQ 12 THEN centerarr=embarr-moonarr/(1+emrat)

   IF target EQ 10 THEN targetarr=embarr+emrat*moonarr/(1+emrat)
   IF center EQ 10 THEN centerarr=embarr+emrat*moonarr/(1+emrat)

 ENDIF
  
 IF target GT 0 AND target NE 10 AND target NE 12 THEN BEGIN
  targetout=target-1
  s=CALL_EXTERNAL('jplde/getephem.so','get_ephem',EphName,jdarr,targetout,FmtOpt,xsize,targetarr)
 ENDIF

 IF center GT 0 AND center NE 10 AND center NE 12 THEN BEGIN
  centerout=center-1
  s=CALL_EXTERNAL('jplde/getephem.so','get_ephem',EphName,jdarr,centerout,FmtOpt,xsize,centerarr)
 ENDIF

 IF center GT 0 THEN targetarr=targetarr-centerarr
 IF KEYWORD_SET(posonly) THEN RETURN,targetarr(*,0:2)/au


 ephstr={EPH,pos:DBLARR(1,3),vel:DBLARR(1,3),lon:0.0d,lat:0.0d,r:0.0d}
 epharr=REPLICATE(ephstr,xsize) 

 FOR i=0l,xsize-1l DO BEGIN
  posvec=targetarr(i,0:2)
  r=SQRT(TOTAL(posvec*posvec))
  epharr(i).pos=posvec/au                        ; au     from center
  epharr(i).vel=targetarr(i,3:5)/au*86400.0d     ; au/day relative to center
  epharr(i).r=r/au                               ; au
  epharr(i).lon=ATAN(posvec(1),posvec(0))        ; rad
  epharr(i).lat=ACOS(posvec(2)/r)                ; rad from pole
 
 ENDFOR



 RETURN,epharr
 END
