;+**********************************************************************
; SCCS id: %W% %U% %G% 
;***********************************************************************
; PROJECT: Cluster UK CDHF
;
; COMPONENT: QVB
;
; LANGUAGE:  IDL
;
; NAME:
;	QCDF_DOYTOEPO
;
; PURPOSE:
;       Convert an epoch structure year, day of year, msecs
;
; CATEGORY:
;	Epoch utilities.
;
; CALLING SEQUENCE:
;	EPOCH=QCDF_DOYTOEPO(year,doy,msecs)
;       
;
; INPUTS:
;         year  INT e.g. 1990
;         doy   INT 1-366
;         [msecs DBL starting from beginnig of day.]
;
; OUTPUTS:
;         EPOCH_IN  : CDF-epoch DOUBLE value
;
; RESTRICTIONS:
;
; COPYRIGHT:
; ---------------------------------------------------------------------
; Copyright (c) 1996 W.J.M.Fraenz
;
; Astronomy Unit, Queen Mary and Westfield College, London, UK.
; This software is distributed WITHOUT ANY WARRANTY, and without even the
; implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
; You may copy or modify this software freely provided that you maintain a
; complete copy of this copyright message with the software.
; ---------------------------------------------------------------------
; MODIFICATION HISTORY:.
;     02/11/95 changed to CSDS standard MF
;     26/06/97 renamed from epotostr MF
;-

FUNCTION QCDF_DOYTOEPO,year, doy, msec


IF doy LE 0 OR doy GT 366 THEN BEGIN
 MESSAGE,'wrong doy for '+STRTRIM(year)+STRTRIM(doy),/inf
 RETURN,0
ENDIF

IF ((year/4)*4 EQ year AND (year/100)*100 NE year) OR (year/400)*400 EQ year $
 THEN moday=[0,31,60,91,121,152,182,213,244,274,305,335] $
 ELSE moday=[0,31,59,90,120,151,181,212,243,273,304,334]

index=WHERE(moday LT doy)
month=MAX(index)
day=doy-moday(month)
month=month+1
IF N_ELEMENTS(msec) LE 0 THEN msec=0.0d
lmsec=LONG(msec)
hour=lmsec/3600000l
minute=(lmsec-hour*3600000l)/60000l
second=(lmsec-hour*3600000l-minute*60000l)/1000l
msecs=msec-hour*3600000l-minute*60000l-second*1000l
IF hour GE 24 THEN BEGIN 
 day=day+1
 hour=hour-24
ENDIF

CDF_EPOCH,epoch,year,month,day,hour,minute,second,msecs,/COMP

IF epoch LE 0 THEN BEGIN
 MESSAGE,'wrong time for '+STRTRIM(year)+STRTRIM(doy)+STRTRIM(msec),/inf
 RETURN,0
ENDIF

RETURN,epoch


END ;======================== end of epoch_string ======================
