;+**********************************************************************
; SCCS id: %W% %U% %G% 
;***********************************************************************
; PROJECT: Cluster UK CDHF
;
; COMPONENT: QVB
;
; LANGUAGE:  IDL
;
; NAME:
;	QCDF_EPOTODOY
;
; PURPOSE:
;       Convert an epoch structure year, day of year, msecs
;
; CATEGORY:
;	Epoch utilities.
;
; CALLING SEQUENCE:
;	QCDF_EPOTODOY,EPOCH_IN,year,doy,msecs,[fulldoy]
;       
;
; INPUTS:
;         EPOCH_IN  : CDF-epoch DOUBLE value
;
;
; OUTPUTS:
;         year  INT e.g. 1990
;         doy   INT 1-366
;         msecs DBL starting from beginnig of day.
;         fulldoy  DBL  yy.dddhhmmss
;
;
; RESTRICTIONS:
;
; COPYRIGHT:
; ---------------------------------------------------------------------
; Copyright (c) 1996 W.J.M.Fraenz
;
; Astronomy Unit, Queen Mary and Westfield College, London, UK.
; This software is distributed WITHOUT ANY WARRANTY, and without even the
; implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
; You may copy or modify this software freely provided that you maintain a
; complete copy of this copyright message with the software.
; ---------------------------------------------------------------------
; MODIFICATION HISTORY:.
;     02/11/95 changed to CSDS standard MF
;     26/06/97 renamed from epotostr MF
;-

PRO QCDF_EPOTODOY, epoch_in, year, doy, msecs, fulldoy

sepoch=SIZE(epoch_in)

IF sepoch(0) NE 0 THEN RETURN
IF sepoch(1) NE 5 THEN RETURN


CDF_EPOCH,epoch_in,year,month,day,hour,minute,second,msec,/BREAK

IF ((year/4)*4 EQ year AND (year/100)*100 NE year) OR (year/400)*400 EQ year $
 THEN moday=[0,31,60,91,121,152,182,213,244,274,305,335] $
 ELSE moday=[0,31,59,90,120,151,181,212,243,273,304,334]

doy=moday(month-1)+day

msecs=(hour*3.6d6)+(minute*6.0d4)+(second*1.0d3)+msec

IF N_PARAMS(0) GT 4 THEN BEGIN

 IF year GE 2000 THEN fulldoy=DOUBLE(year-2000) $
  ELSE fulldoy=DOUBLE(year-1900)
 fulldoy=fulldoy+doy/1000.0d
 fulldoy=fulldoy+hour/100000.0d
 fulldoy=fulldoy+minute/1.0d7
 fulldoy=fulldoy+second/1.0d9

ENDIF


RETURN


END ;======================== end of epoch_string ======================

