;+**********************************************************************
; SCCS id: %W% %U% %G% 
;***********************************************************************
; PROJECT: Cluster UK CDHF
;
; COMPONENT: QVB
;
; LANGUAGE:  IDL
;
; NAME:
;	QCDF_EPOTOSTR
;
; PURPOSE:
;       Convert a CDF epoch double value (msec from year 0) 
;       into a readable date-time string: "YYYY-MM-DD HH:MM:SS.MMM"
;
; CATEGORY:
;	Epoch utilities.
;
; CALLING SEQUENCE:
;	text = QCDF_EPOTOSTR(EPOCH_IN)
;       
;
; INPUTS:
;         EPOCH_IN  : CDF-epoch DOUBLE value
;
;
; KEYWORD PARAMETERS: /DATE  return date only
;                     /TIME  return time only
;                     /COMPRESS short format for file naming
;                     /ISO   return ISO-format
;
; OUTPUTS:
;         QCDF_EPOTOSTR : readable date-time string "YYYY-MM-DD HH:MM:SS.MMM"
;
;
; RESTRICTIONS:
;
; COPYRIGHT:
; ---------------------------------------------------------------------
; Copyright (c) 1996 W.J.M.Fraenz
;
; Astronomy Unit, Queen Mary and Westfield College, London, UK.
; This software is distributed WITHOUT ANY WARRANTY, and without even the
; implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
; You may copy or modify this software freely provided that you maintain a
; complete copy of this copyright message with the software.
; ---------------------------------------------------------------------
; MODIFICATION HISTORY:.
;     02/11/95 changed to CSDS standard MF
;     26/06/97 renamed from epotostr MF
;-

FUNCTION QCDF_EPOTOSTR, epoch_in, date=date,time=time,compress=compress,iso=iso



CDF_EPOCH,epoch_in,year,month,day,hour,minute,second,msec,/BREAK

datestr=''
timestr=''
notset=NOT KEYWORD_SET(date) AND NOT KEYWORD_SET(time)

IF notset OR KEYWORD_SET(date) THEN BEGIN
    IF KEYWORD_SET(compress) THEN $
    datestr= STRING(FORMAT='(I4.4)',year) +$
     STRING(FORMAT='(I2.2)',month)+STRING(FORMAT='(I2.2)',day) $
    ELSE $
    datestr= STRING(FORMAT='(I4.4)',year) +'-' +$
     STRING(FORMAT='(I2.2)',month) +'-'+STRING(FORMAT='(I2.2)',day)
ENDIF

IF notset OR KEYWORD_SET(time) THEN BEGIN
    IF KEYWORD_SET(compress) THEN $
     timestr=STRING(FORMAT='(I2.2)',hour)+$
     STRING(FORMAT='(I2.2)',minute) +STRING(FORMAT='(I2.2)',second) $
    ELSE $
     timestr=STRING(FORMAT='(I2.2)',hour)+':'+$
    STRING(FORMAT='(I2.2)',minute)+ ':' +STRING(FORMAT='(I2.2)',second) +$
    '.' +STRING(FORMAT='(I3.3)',msec)
ENDIF

IF KEYWORD_SET(date) THEN text=datestr

IF KEYWORD_SET(time) THEN text=timestr


IF notset THEN BEGIN
 IF KEYWORD_SET(iso) THEN  text=datestr+'T'+timestr+'Z' ELSE text=datestr+'_'+timestr
ENDIF

RETURN, text


END ;======================== end of epoch_string ======================

