; This function returns TT seconds from J2000.0 for
; a given UTC date and time.
; NAME: QCDF_TDB
; INPUT: year,month,day,hour,minute,sec,msec or arrays thereof
;              UTC date and time (from 1/1/1972), UT1 time for 1900-1972
; KEYWORDS: cdfepoin  calculate UTC date from CDF epoch value first
; OUTPUT: TT (~TDB) seconds from J2000.0 (1/1/2000 12:00 TDB)
; RESTRICTIONS: for array input before 2000.0 it works only if timespan
;               less than 6 months. Also does not work when array spans
;               years before and after 2000.
;
; HISTORY: m.fraenz@qmw.ac.uk 23/8/2001     
;          03/12/2001 array input MF

 FUNCTION QCDF_TDB,year,month,day,hour,minute,sec,msec,cdfepoin=cdfepoin
 
  nelini=N_ELEMENTS(year)-1
  ; if input is in CDF epoch convert back to UT first
  IF KEYWORD_SET(cdfepoin) THEN BEGIN
   nelin=N_ELEMENTS(cdfepoin)
   nelini=nelin-1
   year=LONARR(nelin) & month=LONARR(nelin) & day=LONARR(nelin) & hour=INTARR(nelin)
   minute=INTARR(nelin) & sec=INTARR(nelin) & msec=DBLARR(nelin) &
   FOR i=0l,nelini DO BEGIN
    CDF_EPOCH,cdfepoin(i),yearin,monthin,dayin,hourin,minutein,secin,msecin,/break
    year(i)=yearin & month(i)=monthin & day(i)=dayin & hour(i)=hourin
    minute(i)=minutein & sec(i)=secin & msec(i)=msecin
   ENDFOR
  ENDIF
  ;print,year(0),month(0),day(0),hour(0),minute(0),sec(0),msec(0) 

  ; calculate Julian Date from J2000 (Seidelmann 12.92):
  yvar=LONG(year)+4800l+(LONG(month)-14l)/12l
  jd=(yvar*1461l)/4l
  jd=jd+((LONG(month)-2l-((LONG(month)-14l)/12l)*12l)*367l)/12l
  jd=jd-2451545l ; subtract jd2000.0 to keep numbers small
  yvar=yvar+100l
  jd=DOUBLE(jd-((yvar/100l)*3l)/4l+LONG(day)-32076l)+0.5d ; for 00:00
  ;print,jd,f='(g20.8)'

  ; convert to seconds and add seconds of day:
  jsec=jd*86400d
  IF N_ELEMENTS(hour) GT 0 THEN jsec=jsec+double(hour)*3600d
  IF N_ELEMENTS(minute) GT 0 THEN jsec=jsec+double(minute)*60d
  IF N_ELEMENTS(sec) GT 0 THEN jsec=jsec+double(sec)
  IF N_ELEMENTS(msec) GT 0 THEN jsec=jsec+double(msec)/1000d
 
  ; now add leapseconds:
  IF year(0) GE 2000 THEN BEGIN
   deltat=63.184d
  ENDIF ELSE IF year(0) GE 1972 THEN BEGIN ; Astron.Almanac., page K9
  
   deltat=42.184d
   yarr=[1972,1973,1974,1975,1976,1977,1978,1979,1980,1981, $
        1982,1983,1985,1988,1990,1991,1992,1993,1994,1996,1997,1999,3000]
   marr=[7,1,1,1,1,1,1,1,1,7,7,7,7,1,1,1,7,7,7,1,7,1,0]
  	 
   i=0
   WHILE year(0) GE yarr[i] DO BEGIN 
    deltat=deltat+1d
    i=i+1
   ENDWHILE
   IF i LT 22 AND month(0) LT marr[i-1] THEN deltat=deltat-1d
   IF nelini GT 0 THEN BEGIN
    index=WHERE(year NE year(0) OR month NE month(0))
    IF index[0] NE -1 THEN BEGIN
     index0=index[0]
     IF year[index0] GE yarr[i] OR month[index0] GE 7 THEN jsec(index)=jsec(index)+1d
    ENDIF
   ENDIF
    
  ENDIF ELSE IF year(0) GE 1900 THEN BEGIN ; Meeus, Ch. 10
  
   theta=(jsec/86400d/36525d)+1.0 ; Julian centuries from 1900.0   
   deltat=((((((((58353.42d*theta-232424.66d)*theta+372919.88d)*theta- $
          303191.19d)*theta+124906.15d)*theta-18756.33d)*theta- $
	  2637.8d)*theta+815.20d)*theta+87.24)*theta-2.44d

  ENDIF ELSE BEGIN
   MESSAGE,'only implemented for dates from 1900.0',/inf
   deltat=0d
  ENDELSE
  
  jsec=jsec+deltat

 RETURN,jsec
 END


