;+
; NAME:
;	SCLPRD
;
; PURPOSE:
;	Calculates the scalar product of two arrays of vectors or of
;	row vectors.
;	
; CATEGORY:
;	vector operations
;
; CALLING SEQUENCE:
;
;	scp=SCLPRD(v1,v2)
;
; INPUTS:
;	v1,v2: 2-dim. Arrays of vectors
;		The second index is the vector component,whereas
;		the first index counts the vectors.
;		OR: v1 and v2 are 'row vectors'.
;
; OPTIONAL INPUTS:
;	
; KEYWORD PARAMETERS:
;
; OUTPUTS:
;	scp:	Array of the scalarproducts.
;
; OPTIONAL OUTPUTS:
;
; COMMON BLOCKS:
;
; SIDE EFFECTS:
;
; RESTRICTIONS:
;	If v1 and v2 do not have the same size, the result may be weird.
;
; PROCEDURE:
;	If v1 is just one vector or a row vector
;	(array with first dimension 1), the TOTAL function is used.
;	For actual arrays, this routine uses the TOTAL function
;       with the second argument.
;
; EXAMPLE:
;
; MODIFICATION HISTORY:
; 	Written by:
;
;-
  FUNCTION SCLPRD,v1,v2
   s1=SIZE(v1)
   IF (s1(0) EQ 1) OR (s1(1) EQ 1) THEN scp=TOTAL(v1*v2) $
    ELSE scp=TOTAL(v1*v2,2)
  return,scp
  end

