;
;
      PRO ELLIPX,a,dlm,e,p,dia,omega,xxp,dmas,ierr
;-----------------------------------------------------------------------
;
;     Object :
;     This subroutine computes the variables x, y, z, x',y',z'
;     from the elliptic variables.
;     Inputs:  a   corrected mean semi-major [au]
;              dlm corrected mean long [rad]
;              e   eccentricity
;              p   curly pi= longitude of pericenter = omega+Omega
;              dia inclination [rad]
;              Omega asc.node long [rad]
;              dmas mass ratio planet/Sun
;     Outputs: xxp pos&vel vectors [au]
;
;     Error index :
;     ierr=0 : no error.
;     ierr=1 : error in Kepler equation.
;
;     Intrinsic complex functions :
;     dcmplex : complex number (*16) with two real numbers (*8).
;     dimag :   imaginary part (*8) of complex number (*16).
;     dreal :   real part (*8) of complex number (*16).
;
;     Subroutine called : KEPLER.
;
;-----------------------------------------------------------------------
;

      z=DCOMPLEX(0.0d,0.0d)
      zto=DCOMPLEX(0.0d,0.0d)
      dcmplx=DCOMPLEX(0.0d,0.0d)
      xxp=DBLARR(6)
      ierr=0
;
      xa=a
      xl=dlm
      xk=e*cos(p)
      xh=e*sin(p)
      xq=sin(dia/2)*cos(omega)
      xp=sin(dia/2)*sin(omega)
;
      asr=648000l/3.141592653589793d0
      gk=3548.1876069651d0
;      xfi=sqrt((1.d0)-xk^2-xh^2)
; this is easier:
      xfi=SQRT((1.0d)-e*e)
      xki=sqrt((1.d0)-xq^2-xp^2)
      u=1.d0/((1.d0)+xfi)
; this should be?:
;     u=(1.0d)-xfi
      z=COMPLEX(xk,xh)
      KEPLER,xl,z,zto,r,u,ierr
      IF (ierr NE 0) THEN RETURN
      xcw=DOUBLE(zto)      ; cos(w)=cos(f+p)
      xsw=IMAGINARY(zto)   ; sin(w)=sin(f+p)

      xm=xp*xcw-xq*xsw
      xxx=xa*r             ; distance
      xxp(1-1)=xxx*(xcw-2*xp*xm) ; = cos(Om)cos(om+f)-sin(Om)sin(om+f)cos(i)
      xxp(2-1)=xxx*(xsw+2*xq*xm) ; = sin(Om)cos(om+f)+cos(Om)sin(om+f)cos(i)
      xxp(3-1)=-2*xxx*xki*xm     ; = sin(om+f)sin(i)
      xms=xa*(xh+xsw)/xfi
      xmc=xa*(xk+xcw)/xfi
      xn=gk*(((1.d0)+dmas)/xa^3)^(0.5d0)/asr
      xxp(4-1)=xn*(((-1.d0)+2*xp^2)*xms+2*xp*xq*xmc)
      xxp(5-1)=xn*(((1.d0)-2*xq^2)*xmc-2*xp*xq*xms)
      xxp(6-1)=2*xn*xki*(xp*xms+xq*xmc)

;
      return
      end
;
