; solve Kepler equation by Newton iteration
; Inputs: m mean anommy [rad]
;         e eccentricity
; Return: ea eccentric anomaly [rad]

 FUNCTION KEPLERE,m,e
 
  ; eccentric anommy
  ; startvalue Murray 2.55:

   IF e LT 1.0 THEN $
    ea0=m+(e-0.125d*e^3)*sin(m)+0.5d*e^2*sin(2d*m) $
       +0.375d*e^3*sin(m*3d) $
   ELSE IF m GT 3.0 THEN ea0=m ELSE ea0=e*SINH(m)-m
   ea=ea0

   k=0
   kmax=500

   IF e LT 1.0 THEN BEGIN
   WHILE 1b DO BEGIN
     k=k+1
     dm=m-ea+e*SIN(ea)
     IF ABS(dm) LT 1.0d-12 THEN RETURN,ea      
     IF (k GT kmax) THEN BEGIN
          MESSAGE,'No convergence for m='+STRING(m),/INF  
          RETURN,ea0
     ENDIF
     r=(1.0d)-e*COS(ea)
     ea=ea+dm/r
   ENDWHILE
   ENDIF ELSE BEGIN
   WHILE 1b DO BEGIN
     k=k+1
     dm=m+ea-e*SINH(ea)
     IF ABS(dm) LT 1.0d-12 THEN RETURN,ea      
     IF (k GT kmax) THEN BEGIN
          MESSAGE,'No convergence for m='+STRING(m),/INF  
          RETURN,ea
     ENDIF
     r=e*COSH(ea)-1.0d
     ea=ea+dm/r
   ENDWHILE
   ENDELSE

 RETURN,ea0
 END
