;
;
      FUNCTION ORBIT,a,dlm,e,p,dia,omega,dmas,nokep=nokep
;-----------------------------------------------------------------------
;
;     Object :
;     This subroutine computes the variables x, y, z, x',y',z'
;     from the elliptic variables.
;     Inputs:  a   corrected mean semi-major [au]
;              dlm corrected mean long [rad]
;              e   eccentricity
;              p   curly pi= longitude of pericenter = omega+Omega
;              dia inclination [rad]
;              Omega asc.node long [rad]
;              dmas mass ratio planet/Sun
;     Outputs: DBLARR(counts,6) xxp pos [au] & vel vectors [au/day]
;
;     Error index :
;     ierr=0 : no error.
;     ierr=1 : error in Kepler equation.
;
;
;     Subroutine called : KEPLERE.
;
;-----------------------------------------------------------------------
;

     ;gaussian constant of gravity [au,solar mass,day]:
      k=0.01720209895d
      ierr=0
      counts=N_ELEMENTS(a)
      xxp=DBLARR(counts,6)
      ;calculate parameters relative to pericenter:

      m=(dlm-p) ; MOD (2.0d*!dpi) ; mean anomaly
      index=WHERE(m LT 0.0)
      sqe=SQRT(ABS(1-e*e))
 
      ; solve Kepler eqn (ecc. anomaly and radius):
      ea=m
      ellindex=WHERE(e LT 1.0)
      hypindex=WHERE(e GE 1.0)
      cosnu=ea
      sinnu=ea
      r=a*0.0
      IF KEYWORD_SET(nokep) THEN BEGIN
       IF ellindex(0) NE -1 THEN BEGIN
        cosnu(ellindex)=COS(m(ellindex))
        sinnu(ellindex)=SIN(m(ellindex))
       ENDIF
        IF hypindex(0) NE -1 THEN BEGIN
        cosnu(hypindex)=COSH(m(hypindex))
        sinnu(hypindex)=SINH(m(hypindex))
       ENDIF
       r=ABS(a)*sqe
      ENDIF ELSE BEGIN
       FOR i=0l,counts-1l DO ea(i)=KEPLERE(ABS(m(i)),e(i))
       IF index(0) NE -1 THEN ea(index)=-ea(index)
       ; calculate true anomaly:
       IF ellindex(0) NE -1 THEN BEGIN
         r(ellindex)=(1.0d)-e(ellindex)*COS(ea(ellindex))
         cosnu(ellindex)=(COS(ea(ellindex))-e(ellindex))/r(ellindex)
         sinnu(ellindex)=SIN(ea(ellindex))*sqe(ellindex)/r(ellindex)
       ENDIF
       IF hypindex(0) NE -1 THEN BEGIN
         r(hypindex)=e(hypindex)*COSH(ea(hypindex))-(1.0d)
         cosnu(hypindex)=(-COSH(ea(hypindex))+e(hypindex))/r(hypindex)
         sinnu(hypindex)=SINH(ea(hypindex))*sqe(hypindex)/r(hypindex)
       ENDIF
       nu=ATAN(sinnu,cosnu)
       r=r*ABS(a) 
      ENDELSE

      ;radius vector in orbit [au]:
      rvec=[[cosnu*r],[sinnu*r],[r*0.0d]]
      ; velocity vector [au/d]:
      vorb=SQRT((dmas+1.0d)/ABS(a))*k/sqe
      vvec=[[-sinnu*vorb],[(e+cosnu)*vorb],[vorb*0.0d]]
      
      ; rotate into ecliptic system:

      FOR i=0l,counts-1l DO BEGIN
       erot=TRANSPOSE(GPOLROT(omega(i),dia(i),p(i)-omega(i)))
       xxp(i,0:2)=rvec(i,*)#erot
       xxp(i,3:5)=vvec(i,*)#erot
      ENDFOR

;
;
      return,xxp
      end
;
