;####################DATA FROM F77 ROUTINE PRCUPDAT.F BY J.L. Simon

PRO PRCUPDAT,prc,obl,rme,rve,rma,rju,rsa,rur,rne,nlu,iers92=iers92


;     Input parameters :
;
;     prc   general precession in "/1000y (double precision).
;     obl   obliquity J2000 in arcseconds (double precision).
;     rme   ratio mass Mercury / mass Sun (double precision)
;     rve   ratio mass Venus   / mass Sun (double precision)
;     rma   ratio mass Mars    / mass Sun (double precision)
;     rju   ratio mass Jupiter / mass Sun (double precision)
;     rsa   ratio mass Saturn  / mass Sun (double precision)
;     rur   ratio mass Uranus  / mass Sun (double precision)
;     rne   ratio mass Neptune / mass Sun (double precision)
;     nlu   logical unit of output file (integer)

;     Default values (IAU 1976):
;
;     general precession :                50288.200 "/1000y.
;     obliquity in J2000 :                84381.412 " (23x26'21.412").
;     Ratio  Sun mass / Mercury mass :    6023600     IAU 1976
;     Ratio  Sun mass / Venus   mass :    408523.5    IAU 1976
;     Ratio  Sun mass / E-M baryc. mass : 328900.5    IAU 1976
;     Ratio  Sun mass / Mars    mass :    3098710     IAU 1976
;     Ratio  Sun mass / Jupiter mass :    1047.355    IAU 1976
;     Ratio  Sun mass / Saturn mass :     3498.5      IAU 1976
;     Ratio  Sun mass / Uranus  mass :    22869       IAU 1976
;     Ratio  Sun mass / Neptune mass :    19314       IAU 1976
;
;
;    Default values of constants.
;
      prc0=50288.200d0
      obl0=84381.412d0
      rme0=6023600.d0
      rve0=408523.5d0
      rma0=3098710.d0
      rju0=1047.355d0
      rsa0=3498.5d0
      rur0=22869.d0
      rne0=19314.d0
;
;     New values for masses of planets (IERS standard 1992).
;
IF KEYWORD_SET(iers92) THEN BEGIN
      rme=6023600.d0
      rve=408523.71d0
      rma=3098708.d0
      rju=1047.3486d0
      rsa=3497.90d0
      rur=22902.94d0
      rne=19412.24d0
      nlu=10
ENDIF

;     Initialization of corrections.
;
      zero=0.d0 & dp=0.d0  & de=0.d0  & dme=0.d0  & dve=0.d0
      dma=0.d0  & dju=0.d0  & dsa=0.d0  & dur=0.d0  & dne=0.d0
;
      IF (prc NE zero) THEN BEGIN
         dp=prc-prc0
         prc0=prc
      ENDIF
;
      IF (obl NE zero) THEN BEGIN
         de=obl-obl0
         obl0=obl
      ENDIF 
;
      IF (rme NE zero) THEN BEGIN
         dme=-(rme-rme0)/rme0
         rme0=rme
      ENDIF 
;
      IF (rve NE zero) THEN BEGIN
         dve=-(rve-rve0)/rve0
         rve0=rve
      ENDIF 
;
      IF (rme NE zero) THEN BEGIN
         dma=-(rma-rma0)/rma0
         rma0=rma
      ENDIF 
;
      IF (rju NE zero) THEN BEGIN
         dju=-(rju-rju0)/rju0
         rju0=rju
      ENDIF 
;
      IF (rsa NE zero) THEN BEGIN
         dsa=-(rsa-rsa0)/rsa0
         rsa0=rsa
      ENDIF 
;
      IF (rur NE zero) THEN BEGIN
         dur=-(rur-rur0)/rur0
         rur0=rur
      ENDIF 
;
      IF (rne NE zero) THEN BEGIN
         dne=-(rne-rne0)/rne0
         rne0=rne
      ENDIF 
;
;     Corrections of numerical expressions of precession.
;
      ss(0,1)=ss(0,1)                                                 $ ; T0 t1
          +3.0d4*dme-29.d4*dju-5.7d4*dsa-0.04d4*dne
      ss(1,1)=ss(1,1)                                                 $ ; T1 t1
          -0.0023d4*dp -39.d4*dju-3.1d4*dsa
;
      sc(0,1)=sc(0,1)                                                 $ ; T0 t1
          -2.7d4*dme-286.d4*dve-159.d4*dju-13.0d4*dsa-0.04d4*dne
      sc(1,1)=sc(1,1)                                                 $ ; T1 t1
          +1.4d4*dsa
      sc(2,1)=sc(2,1)                                                 $ ; T2 t1
          +0.0004d4*dp
;
      spi(0,1)=spi(0,1)                                               $ ; T0 t1
          +3.0d4*dme+291.d4*dve+156.d4*dju+12.4d4*dsa+0.04d4*dne
;
      cpi(0,0)=cpi(0,0)                                               $ ; T0 t0
          -1228.d4*dme-18371.d4*dve-2410.d4*dma+18994.d4*dju+2995.d4*dsa $ ;
          -7.d4*dur+18.3d4*dne
      cpi(1,0)=cpi(1,0)                                               $ ; T1 t0
          +dp $ ;
          +92.d4*dme+10490.d4*dve+6018.d4*dju+502.d4*dsa+3.d4*dur $ ;
          +1.8d4*dne
      cpi(2,0)=cpi(2,0)                                               $ ; T2 t0
          +0.003d4*dp
      cpi(0,1)=cpi(0,1)                                               $ ; T0 t1
          +46.d4*dme+5245.d4*dve+3009.d4*dju+251.d4*dsa+1.5d4*dur $ ;
          +0.9d4*dne
;
      p(0,1)=p(0,1)                                                   $ ; T0 t1
          +dp
      p(1,1)=p(1,1)                                                   $ ; T1 t1
          +0.0062d4*dp-0.0016d4*de $ ;
          +1.8d4*dme+190.d4*dve+106.d4*dju+8.7d4*dsa+0.03d4*dne
      p(0,2)=p(0,2)                                                   $ ; T0 t2
          +0.0031d4*dp $ ;
          +53.d4*dju+4.4d4*dsa
;
      theta(0,1)=theta(0,1)                                           $ ; T0 t1
          +0.3978d4*dp+0.2236d4*de $ ;
          +2.8d4*dme-27.d4*dju-5.2d4*dsa-0.03d4*dne
      theta(1,1)=theta(1,1)                                           $ ; T1 t1
          -0.0017d4*dp $ ;
          -29.d4*dju-2.3d4*dsa
      theta(0,2)=theta(0,2)                                           $ ; T0 t2
          -0.0008d4*dp  -1.2d4*dsa
      theta(0,3)=theta(0,3)                                           $ ; T0 t3
          -0.0025d4*dp
;
      zeta(0,1)=zeta(0,1)                                             $ ; T0 t1
          +0.4588d4*dp-0.0485d4*de   +1.1d4*dsa
      zeta(1,1)=zeta(1,1)                                             $ ; T1 t1
          +0.0038d4*dp  +64.d4*dju+5.2d4*dsa
      zeta(0,2)=zeta(0,2)                                             $ ; T0 t2
          +0.0009d4*dp   +1.3d4*dsa
      zeta(0,3)=zeta(0,3)                                             $ ; T0 t3
          +0.0011d4*dp
;
      z(0,1)=z(0,1)                                                   $ ; T0 t1
          +0.4588d4*dp-0.0485d4*de  +1.1d4*dsa
      z(1,1)=z(1,1)                                                   $ ; T1 t1
          +0.0038d4*dp     +64.d4*dju+5.2d4*dsa
      z(0,2)=z(0,2)                                                   $ ; T0 t2
          +0.0028d4*dp     +49.d4*dju+4.0d4*dsa
      z(0,3)=z(0,3)                                                   $ ; T0 t3
          +0.0011d4*dp
;
      epsil(0,0)=epsil(0,0)                                           $ ; T0 t0
          +de
      epsil(1,0)=epsil(1,0)                                           $ ; T1 t0
          -2.7d4*dme-286.d4*dve-159.d4*dju-13.0d4*dsa-0.04d4*dne
      epsil(0,1)=epsil(0,1)                                           $ ; T0 t1
          -2.7d4*dme-286.d4*dve-159.d4*dju-13.0d4*dsa-0.04d4*dne
      epsil(1,1)=epsil(1,1)                                           $ ; T1 t1
          +1.4d4*dsa
      epsil(2,1)=epsil(2,1)                                           $ ; T2 t1
          +0.0004d4*dp
      epsil(1,2)=epsil(1,2)                                           $ ; T1 t2
          +0.0004d4*dp
;
      omega(0,0)=omega(0,0)                                           $ ; T0 t0
          +de
      omega(1,0)=omega(1,0)                                           $ ; T1 t0
          -2.7d4*dme-286.d4*dve-159.d4*dju-13.0d4*dsa-0.04d4*dne
      omega(1,2)=omega(1,2)                                           $ ; T1 t2
          -0.0005d4*dp
      omega(0,3)=omega(0,3)                                           $ ; T0 t3
          -0.0003d4*dp
;
      psi(0,1)=psi(0,1)                                               $ ; T0 t1
          +dp-0.0013d4*de $ ;
          +7.0d4*dme+156.d4*dve-67.d4*dju-13.1d4*dsa-0.09d4*dne
      psi(1,1)=psi(1,1)                                               $ ; T1 t1
          +0.0010d4*dp   +1.3d4*dsa
      psi(0,2)=psi(0,2)                                               $ ; T0 t2
          -0.0021d4*dp+0.0021d4*de   -36.d4*dju-3.0d4*dsa
;
      chi(0,1)=chi(0,1)                                               $ ; T0 t1
          -0.0012d4*de  $ ;
          +7.7d4*dme+170.d4*dve-73.d4*dju-14.3d4*dsa-0.10d4*dne
      chi(1,1)=chi(1,1)                                               $ ; T1 t1
          -0.0057d4*dp+0.0021d4*de $ ;
          -1.6d4*dme-175.d4*dve-97.d4*dju-8.0d4*dsa-0.03d4*dne
      chi(0,2)=chi(0,2)                                               $ ; T0 t2
          -0.0057d4*dp+0.0027d4*de $ ;
          -1.6d4*dme-175.d4*dve-97.d4*dju-8.0d4*dsa-0.03d4*dne
      chi(2,2)=chi(2,2)                                               $ ; T2 t2
          +0.0003d4*dp
      chi(1,3)=chi(1,3)                                               $ ; T1 t3
          +0.0003d4*dp
;
RETURN
END
