; This function returns true JDE200 geometric equatorial or ecliptic position
; on the equinox of date for a given object relative to center.
;
;  tj0  DBLARR(counts) distance in Julian centuries from J2000.0=JD 2451545.0d
;
; targets: 0:   "SSB"
;          1:    "Mercury" 
;          2:    "Venus"
;          3:    EMB
;          4:    "Mars"
;          5:    "Jupiter"
;          6:    "Saturn"
;          7:    "Uranus";
;          8:    "Neptune"
;          9:    "Pluto"
;         10:    "Moon"
;         11:    "Sun"
;         12:    "Earth"
; KEYWORDS:
;         center by default SSB
; aberr  0-3 include light aberration of order 1-3
; nonut  0/1 exclude nutation
; ecliptic 0/1 return ecliptic pos and express angles in lon/lat (for debugging)
; order  1-3 calculate aberration, nutation, precession to this order.
;
; RETURNS: array of structures:
;  ephstr={EPH,pos:DBLARR(1,3),vel:DBLARR(1,3),lon:0.0d,lat:0.0d,r:0.0d}
;  in au,au/day,radian
;
;
 FUNCTION TRUEJPL,tj,target,center=center,aberr=aberr,nonut=nonut,noprec=noprec, $
     ecliptic=ecliptic,order=order,epsfirst=epsfirst,test=test

  IF KEYWORD_SET(center) EQ 0b THEN center=0
  IF KEYWORD_SET(order) EQ 0b THEN order=3
  ecliptic=KEYWORD_SET(ecliptic)
  precset=KEYWORD_SET(noprec) EQ 0b
  nutset=KEYWORD_SET(nonut) EQ 0b
  epsfirst=KEYWORD_SET(epsfirst)
  j2000set=KEYWORD_SET(noprec) OR epsfirst
  test=KEYWORD_SET(test)
  equatorial=ecliptic EQ 0

  dj=tj*36525.0d
  jdarr=dj+2451545.0d
  pi2=!dpi/2.0d
  counts=N_ELEMENTS(dj)

  ;jplde:
  ; get geometric positions on equinox J2000.0

  IF KEYWORD_SET(aberr) THEN BEGIN
 
    eph=ABERRATION(jdarr,target,test=test,order=aberr)
      
  ENDIF ELSE BEGIN

    eph=GETJPL(target,jdarr,center=center)

  ENDELSE
  IF counts GT 1 THEN posvec=TRANSPOSE(eph.pos) ELSE posvec=eph.pos
  ephtrue=eph

  IF test THEN BEGIN
   print,'RA:',MINSEC(eph.lon,/r,equ=(ecliptic EQ 0b))
   print,'DE:',MINSEC(pi2-eph.lat,/r,/decl)
   print,'r:',eph.r
  ENDIF
  ;print,eph

  ;print,posvec/eph.r
  ephang=VPHTHR(posvec)
 
  ;print,TRANSPOSE(posvec)/eph(0).r
  ;print,'RAab:',MINSEC(ephang(0),/r,equ=(ecliptic EQ 0b))
  ;print,'DEab:',MINSEC(pi2-ephang(1),/r,/decl)

  ;ptrue=[0.211279859d,0.89673735d,0.388873946d]
  ;angp=VPHTHR(ptrue)
  ;print,'RAab:',MINSEC(angp(0),/r,equ=(ecliptic EQ 0b))
  ;print,'DEab:',MINSEC(pi2-angp(1),/r,/decl)

  


  IF precset THEN prec=PRECESS(tj*0.0d,tj,equator=(epsfirst EQ 0b),order=order)
  IF ecliptic THEN eps=EPSILON(tj,j2000=j2000set,true=nutset,order=order)
  IF nutset THEN nut=NUTATION(tj,dpde,order=order)
  ;print,rmat(0,*,*)
  ;print,nut(0,*,*)
  
 
  FOR i=0l,counts-1l DO BEGIN
    ephdate=posvec(i,*)
    ephvel=eph(i).vel
    IF ecliptic AND epsfirst THEN BEGIN
     ephdate=ephdate#GPOLROT(0.0d,eps(i),0.0d)
     ephvel=ephvel#GPOLROT(0.0d,eps(i),0.0d)
    ENDIF
    IF precset THEN BEGIN
      ephdate=ephdate#REFORM(prec(i,*,*))
      ephvel=ephvel#REFORM(prec(i,*,*))
    ENDIF
    IF nutset THEN BEGIN
      ephdate=ephdate#REFORM(nut(i,*,*))
      ephvel=ephvel#REFORM(nut(i,*,*))
    ENDIF
    ;print,ephdate,ephvel
    IF ecliptic AND (epsfirst EQ 0b) THEN BEGIN
     IF nutset THEN rotang=dpde(i,0) ELSE rotang=0.0d
     ephdate=ephdate#GPOLROT(0.0d,eps(i),rotang)
     ephvel=ephvel#GPOLROT(rotang,eps(i),0.0d)
    ENDIF
    ephang=VPHTHR(ephdate)
    velang=VPHTHR(ephvel)
    IF ecliptic THEN BEGIN
;      IF nutset THEN ephang(0)=ephang(0)-dpde(i,0)
;      IF nutset THEN ephang(1)=ephang(1)-dpde(i,1)

;      IF nutset THEN velang(0)=velang(0)-dpde(i,0)
    ENDIF 
    ;print,ephang,velang
    ephtrue(i).pos=PHTHRV(ephang)
    ephtrue(i).vel=PHTHRV(velang)
    ephtrue(i).lon=ephang(0)
    ephtrue(i).lat=ephang(1)
    IF test THEN BEGIN
     print,'LON:',STRING(MINSEC(ephang(0),/r,equ=(ecliptic EQ 0b)),f='(g20.9)')
     print,'LAT:',STRING(MINSEC(pi2-ephang(1),/r,/decl),f='(g20.9)')
     print,'r:',STRING(ephang(2),f='(g20.7)')
    ENDIF
  ENDFOR
 ; help,epsfirst,order,nutset,precset,j2000set,aberr
  
 RETURN,ephtrue
 END
